<?php
/**
 * Piwik - Open source web analytics
 * 
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 * @version $Id: Envole.php 2967 2010-08-20 15:12:43Z vipsoft $
 * 
 * @category Piwik_Plugins
 * @package Piwik_Envole
 */

/**
 *
 * @package Piwik_Envole
 */
class Piwik_Envole extends Piwik_Plugin
{	
	public function getInformation()
	{
		$info = array(
			'name' => 'Envole',
			'description' => 'Envole  get user Info from EnvOLE',
			'author' => 'Lucile Coutouly',
			'author_homepage' => 'http://dev.ac-creteil.fr',
			'version' => '0.3',
			'translationAvailable' => true,
			'TrackerPlugin' => true, // this plugin must be loaded during the stats logging
		);
		return $info;
	}
	protected $EnvoleDb = null;
	public function __destruct()
	{
		if(!is_null($this->EnvoleDb))
		{
			Envole_close($this->EnvoleDb);
		}
	}
	
	public function install()
	{
		// add column in the visit table
		$query = "ALTER IGNORE TABLE `".Piwik_Common::prefixTable('log_visit')."` " .
				"ADD `Envole_rne` VARCHAR( 8 ) NULL, " .
				"ADD `Envole_group` VARCHAR( 150 ) NULL, " .
				"ADD `Envole_user` VARCHAR( 4 ) NULL, " . 
				"ADD `Envole_provenance` VARCHAR( 250 ) NULL ";
				
		
		// if the column already exist do not throw error. Could be installed twice...
		try {
			Zend_Registry::get('db')->query($query);
		}
		catch(Exception $e){
		}
	}
	
	function uninstall()
	{
		$query = "ALTER TABLE `".Piwik_Common::prefixTable('log_visit')."` " . 
			"DROP `Envole_rne`, " . 
			"DROP `Envole_provenance`, " .
			"DROP `Envole_user`, " . 
			"DROP `Envole_group`, " . 
		Zend_Registry::get('db')->query($query);
	}
	function getListHooksRegistered()
	{
		$hooks = array(
			'ArchiveProcessing_Day.compute' => 'archiveDay',
			'ArchiveProcessing_Period.compute' => 'archivePeriod',
			'Tracker.newVisitorInformation' => 'logEnvoleInfo',
			'WidgetsList.add' => 'addWidgets',
			'Menu.add' => 'addMenu',
			//'Goals.getReportsWithGoalMetrics' => 'getReportsWithGoalMetrics',
			'API.getReportMetadata' => 'getReportMetadata',
		  //  'API.getSegmentsMetadata' => 'getSegmentsMetadata'
		);
		return $hooks;
		
		
	}

	public function getReportMetadata($notification) 
	{
		$reports = &$notification->getNotificationObject();
		$reports[] = array(
			'category' => Piwik_Translate('VisitsSummary_VisitsSummary'),
			'name' => Piwik_Translate('Envole_WidgetProvenance'),
			'module' => 'Envole',
			'action' => 'getVisitInformationPerProvenance',
			'dimension' => Piwik_Translate('Envole_ColumnProvenance'),
		);
		
		$reports[] = array(
			'category' => Piwik_Translate('VisitsSummary_VisitsSummary'),
			'name' => Piwik_Translate('Envole_WidgetRne'),
			'module' => 'Envole',
			'action' => 'getVisitInformationPerRne',
			'dimension' => Piwik_Translate('Envole_ColumnRne'),
		);
	}

	/**
	 * Get segments meta data
	 *
	 * @param Piwik_Event_Notification $notification
	 */
	public function getSegmentsMetadata($notification)
	{
		$segments =& $notification->getNotificationObject();
	   
	    	$segments[] = array(
		        'type' => 'dimension',
		        'category' => 'Visit',
		        'name' => $columnName,
		        'segment' => $segment,
		        'acceptedValues' => $acceptedValues,
		        'sqlSegment' => $sqlSegment,
	            'sqlFilter' => isset($sqlFilter) ? $sqlFilter : false,
	    	);
	   
	}
	
	function addWidgets()
	{
		Piwik_AddWidget( 'VisitsSummary_VisitsSummary', 'Envole_WidgetProvenance', 'Envole', 'getVisitInformationPerProvenance');
		Piwik_AddWidget( 'VisitsSummary_VisitsSummary', 'Envole_WidgetRne', 'Envole', 'getVisitInformationPerRne');
		Piwik_AddWidget( 'VisitsSummary_VisitsSummary', 'Envole_WidgetGroup', 'Envole', 'getVisitInformationPerGroup');
	}
	
	function addMenu()
	{
		Piwik_AddMenu('General_Visitors', 'Envole_SubmenuEnvole', array('module' => 'Envole', 'action' => 'index'));
	}

	function getReportsWithGoalMetrics( $notification )
	{
		$segments =& $notification->getNotificationObject();
		$segments[] = array('category'  => Piwik_Translate('Envole_ColumnRne'),
                			'name'   => Piwik_Translate('Envole_ColumnRne'),
                			'module' => 'Envole',
                			'action' => 'getVisitInformationPerRne',
    	);
	}
	
	function archivePeriod( $notification )
	{
		
		$archiveProcessing = $notification->getNotificationObject();
		$maximumRowsInDataTable = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_standard;
		$dataTableToSum = array( 
				'Envole_Provenance',
				'Envole_Rne',
				'Envole_Group'
		);
		$nameToCount = $archiveProcessing->archiveDataTable($dataTableToSum, null, $maximumRowsInDataTable);

		//$archiveProcessing->insertNumericRecord('Envole_distinctProvenance',	$nameToCount['UserCountry_country']['level0']);
	}
	
	public function archiveDay( $notification )
	{
		$archiveProcessing = $notification->getNotificationObject();
		
		
		
		$maximumRowsInDataTable = Zend_Registry::get('config')->General->datatable_archiving_maximum_rows_standard;
		$columnToSortByBeforeTruncation = Piwik_Archive::INDEX_NB_VISITS;
		$this->archiveProcessing = $archiveProcessing;
			
		$recordName = 'Envole_provenance';
		$labelSQL = "Envole_provenance";
		$interestByProvenance = $archiveProcessing->getArrayInterestForLabel($labelSQL);
		$tableProvenance = $archiveProcessing->getDataTableFromArray($interestByProvenance);
		$archiveProcessing->insertBlobRecord($recordName, $tableProvenance->getSerialized($maximumRowsInDataTable, null, $columnToSortByBeforeTruncation));
		destroy($tableProvenance);	

		
		
		$recordName = 'Envole_group';
		$labelSQL = "Envole_group";
		$interestByGroup = $archiveProcessing->getArrayInterestForLabel($labelSQL);
		$tableGroup = $archiveProcessing->getDataTableFromArray($interestByGroup);
		$archiveProcessing->insertBlobRecord($recordName, $tableGroup->getSerialized($maximumRowsInDataTable, null, $columnToSortByBeforeTruncation));
		destroy($tableGroup);
		
		$recordName = 'Envole_rne';
		$labelSQL = "Envole_rne";
		$interestByRne = $archiveProcessing->getArrayInterestForLabel($labelSQL);
		$tableRne = $archiveProcessing->getDataTableFromArray($interestByRne);
		$archiveProcessing->insertBlobRecord($recordName, $tableRne->getSerialized($maximumRowsInDataTable, null, $columnToSortByBeforeTruncation));
		destroy($tableRne);	
			
		
	}
	
	
	
	protected function archiveDayAggregateGoals($archiveProcessing)
	{	
		/*
		$query = $archiveProcessing->queryConversionsBySingleSegment("HOUR(server_time)");
		$goalByRne = array();
		while($row = $query->fetch())
		{
			$goalByRne[$row['label']][$row['idgoal']] = $archiveProcessing->getGoalRowFromQueryRow($row);
		}
		$goalByRne = $this->convertRneToProvenancezone($goalByRne, $archiveProcessing);
		foreach($goalByRne as $hour => $goals)
		{
			$this->interestByRne[$hour][Piwik_Archive::INDEX_GOALS] = $goals;
		}
		$archiveProcessing->enrichConversionsByLabelArray($this->interestByRne);
		*/
	}
	
	protected function archiveDayRecordInDatabase($archiveProcessing)
	{
		$tableProvenance = $archiveProcessing->getDataTableFromArray($this->interestByProvenance);
		//$this->makeSureAllHoursAreSet($tableProvenance, $archiveProcessing);
		$archiveProcessing->insertBlobRecord('Envole_Provenance', $tableProvenance->getSerialized());
		$archiveProcessing->insertNumericRecord('Envole_distinctProvenance', $tableProvenance->getRowsCount());
		destroy($tableProvenance);
		
		$tableRne = $archiveProcessing->getDataTableFromArray($this->interestByRne);
		//$this->makeSureAllHoursAreSet($tableRne, $archiveProcessing);
		$archiveProcessing->insertBlobRecord('Envole_Rne', $tableRne->getSerialized());
		$archiveProcessing->insertNumericRecord('Envole_distinctRne', $tableRne->getRowsCount());
		destroy($tableRne);
		
		$tableGroup = $archiveProcessing->getDataTableFromArray($this->interestByGroup);
		//$this->makeSureAllHoursAreSet($tableRne, $archiveProcessing);
		$archiveProcessing->insertBlobRecord('Envole_Group', $tableGroup->getSerialized());
		//$archiveProcessing->insertNumericRecord('Envole_distinctGroup', $tableRne->getRowsCount());
		destroy($tableGroup);
		
		/*
		$tableProvenance = $archiveProcessing->getDataTableFromArray($this->interestByProvenance);
		$archiveProcessing->insertBlobRecord('UserEnvole_provenance', $tableProvenance->getSerialized());
		$archiveProcessing->insertNumericRecord('UserEnvole_distinctProvenance', $tableProvenance->getRowsCount());
		destroy($tableProvenance);
		
		$tableRne = $archiveProcessing->getDataTableFromArray($this->interestByRne);
		$archiveProcessing->insertBlobRecord('UserEnvole_rne', $tableRne->getSerialized());
		$archiveProcessing->insertNumericRecord('UserEnvole_distinctRne', $tableRne->getRowsCount());
		destroy($tableRne);
		
		$tableGroup = $archiveProcessing->getDataTableFromArray($this->interestByGroup);
		$archiveProcessing->insertBlobRecord('UserEnvole_group', $tableGroup->getSerialized());
		destroy($tableGroup);
		*/
	}

	
	public function logEnvoleInfo($notification)
	{
		/**
		/* Debuggage 
		*/
		
		/*
	  	require_once('/var/www/html/FirePHPCore/FirePHP.class.php');
		$firephp = FirePHP::getInstance(true);
		$options = array('maxObjectDepth' => 10,
                 'maxArrayDepth' => 20,
                 'useNativeJsonEncode' => true,
                 'includeLineNumbers' => true);
 
		$firephp->getOptions();
		$firephp->setOptions($options);
		$firephp->log('Plain Message');     // or FB::
		$firephp->info('Info Message');     // or FB::
		$firephp->warn('Warn Message');     // or FB::
		$firephp->error('Error Message');   // or FB::
		 
		$firephp->log('Message','Optional Label');
		 
		
		 
		$firephp->setObjectFilter('ClassName',
				           array('MemberName'));
		*/
		
		$visitorInfo =& $notification->getNotificationObject();
		
		
		try {
			//$hostnameprovenance = $this->getHostnameProvenance($_SERVER["REMOTE_ADDR"]);
		
		
			$data =json_decode(html_entity_decode(Piwik_Common::getRequestVar("data")));
		
			$visitorInfo['Envole_group']=$data->group;
			$visitorInfo['Envole_rne']=$data->rne;
			$visitorInfo['Envole_user']=$data->userId;
			$visitorInfo['Envole_provenance'] = $this->getHostnameProvenance($data->provenance);
			
			
		}
		catch(Exception $e){
			
		}
		
	}

	
	
	
	public function footerUserprovenance($notification)
	{
		$out =& $notification->getNotificationObject();
		$out .= '<h2>Envole provenance</h2>';
		$out .= Piwik_FrontController::getInstance()->fetchDispatch('Envole','getEnvoleprovenance');
		$out .= '<h2>Envole Continent</h2>';
		$out .= Piwik_FrontController::getInstance()->fetchDispatch('Envole','getEnvoleContinent');
	}
	
	private function getHostnameProvenance($hostname)
	{
		
			$e = explode('.', $hostname);
			$s = sizeof($e);
			
			// if extension not correct
			if(($e[0]=="172"&&$e[1]=="30")||($e[0]=="172"&&$e[1]=="16")||($e[0]=="10"&&($e[1]=="77"||$e[1]=="93"||$e[1]=="94")))
			{
				return 'interne';
			}
			else
			{
				return 'externe';
			}
		
	}
}

